==> haskell-mono-traversable-1.0.21.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-BM1Dg3UQRn1HIYXOP7WYj4
key:                  mono-traversable-1.0.21.0-BM1Dg3UQRn1HIYXOP7WYj4
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  435612f0009b505cac048776f3b7f3b3
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-BM1Dg3UQRn1HIYXOP7WYj4
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-HmFtE5Wyl97MxSGTvKCoh
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG
    vector-algorithms-0.9.1.0-Ct9tyVqzjfV3aVlvQ8CtWN

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.21.0-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-OrkWsnC17rEcOZyQt9FHq
key:                  mono-traversable-1.0.21.0-OrkWsnC17rEcOZyQt9FHq
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  80300592917012279073ed161e36dec6
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-OrkWsnC17rEcOZyQt9FHq
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-EdBgVbn6YIuE9bA3dwmz04
    split-0.2.5-42FGdeEiiUOLLQR1FNYPlK text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    vector-algorithms-0.9.1.0-GRr0MFFjhy0G1ooAnxyoxp

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
